#
# Cookbook:: pf_chef_wrapper_nagios_server
# Recipe:: default
#
# Copyright:: 2018, PubFactory, All Rights Reserved.

## Common Data ##

include_recipe 'pf_chef_wrapper_nagios_server::commands'
include_recipe 'pf_chef_wrapper_nagios_server::contacts'
include_recipe 'pf_chef_wrapper_nagios_server::contactgroups'
include_recipe 'pf_chef_wrapper_nagios_server::hosts'
include_recipe 'pf_chef_wrapper_nagios_server::hostgroups'
include_recipe 'pf_chef_wrapper_nagios_server::resources'
include_recipe 'pf_chef_wrapper_nagios_server::services'
include_recipe 'pf_chef_wrapper_nagios_server::timeperiods'

node['pf_chef_wrapper_nagios_server']['monitor_sites'].each do |site|
	next if site == 'manual'
	node_list = search(:node, "tags:site_#{site} AND -chef_environment:_default")

	unless node_list.empty?
		include_recipe "pf_chef_wrapper_nagios_server::site_#{site}"

		environment_list = node_list.map { |node| node.chef_environment }.uniq
		environment_list.each do |environment|
			environment_members = node_list.select { |node| node.chef_environment == environment }.map { |node| node.name }
			nagios_hostgroup "#{environment}_#{site}" do
				options 'members' => environment_members
			end
		end

		nagios_hostgroup "site_#{site}" do
			options 'hostgroup_members' => environment_list.map { |environment| "#{environment}_#{site}" }
		end

		node_list.each do |node|
                  if node.chef_environment == "dev"
			nagios_host node.name do
				options 'use' => 'generic-host',
					'host_name' => node.name,
					'contact_groups' => 'ops,admins_email_only'
			end
                  else
			nagios_host node.name do
				options 'use' => 'generic-host',
					'host_name' => node.name,
					'contact_groups' => 'ops,cs_escalation'
                        end
                  end
		end

		group_list = node_list.collect_concat { |node| node['tags'].select { |tag| tag =~ /^group_.*$/ } }.uniq.map { |group| group.sub(/^group_/,'') }
		unless group_list.empty?
			group_list.each do |group|
				group_members = node_list.select { |node| node['tags'].select { |tag| tag == "group_#{group}" }.count > 0 }.map { |node| node.name }
				nagios_hostgroup group do
					options 'members' => group_members
				end
				include_recipe "pf_chef_wrapper_nagios_server::group_#{group}"
			end
		end
	end
end

## Manual Hosts ##
if node['pf_chef_wrapper_nagios_server']['monitor_sites'].include? 'manual'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ams.hup.harvard.edu'
	include_recipe 'pf_chef_wrapper_nagios_server::host_berghahnjournals.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_bioscientifica.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_bloomsburyprofessionalonline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_brill.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_daredictionary.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_elgaronline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_elibrary.imf.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_jnccn.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_journals.ashs.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_journals.humankinetics.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_jurabibliotek.dk'
	include_recipe 'pf_chef_wrapper_nagios_server::host_loebclassics.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_manchesterhive.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_null'
	include_recipe 'pf_chef_wrapper_nagios_server::host_nephsap.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordaasc.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordartonline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordbiblicalstudies.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordbibliographies.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxforddnb.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordislamicstudies.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordmusiconline.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordwesternmusic.com'
        include_recipe 'pf_chef_wrapper_nagios_server::host_oxfordreference.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_pubfactory.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_pubs.nctm.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_sipriyearbook.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_staging.daredictionary.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_thejns.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ukwhoswho.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_akjournals.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_publications.ashp.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_journals.ametsoc.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ajtmh.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_avma.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_japmaonline.org'
	include_recipe 'pf_chef_wrapper_nagios_server::host_bristoluniversitypressdigital.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_kglmeridian.com'
	include_recipe 'pf_chef_wrapper_nagios_server::host_ama-guides.ama-assn.org'
end

## This is a hack! Don't use it unless you really have to
if node['pf_chef_wrapper_nagios_server']['monitor_sites'].include? 'manual-irl'
	include_recipe 'pf_chef_wrapper_nagios_server::manual_irl'
end

## Run nagios setup ##

include_recipe 'nagios::default'

## Add slack integration

package 'libwww-perl'
package 'libcrypt-ssleay-perl'

# Ruby
package 'ruby'

gem_package 'aws-sdk-s3' do 
  action :install
end

gem_package 'yaml' do
  action :install
end

cookbook_file '/usr/local/bin/slack_nagios.pl' do
	source 'slack_nagios.pl'
	owner 'root'
	group 'root'
	mode '0755'
	action :create
end

##
# Need pip3 installed and libraries
# sudo apt install python3-pip
# pip3 install nagiosplugin
# pip3 install flatten_json

cookbook_file '/usr/local/bin/health_check.py' do
	source 'health_check.py'
	owner 'root'
	group 'root'
	mode '0755'
	action :create
end

## Don't use internal authentication ##

edit_resource(:template, '/etc/apache2/sites-available/nagios.conf') do
	source 'apache2.conf.erb'
	cookbook 'pf_chef_wrapper_nagios_server'
end
