nagios_host 'japmaonline.org' do
	options 'use' => 'noping-host-https-apma',
		'alias' => 'APMA',
		'address' => 'japmaonline.org',
		'contact_groups' => 'cs_escalation,apma',
		'notes' => 'APMA Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/APMA/pages/2732523523/Server+Setup+-+American+Podiatric+Medical+Association+APMA'
end
nagios_host 'admin.japmaonline.org' do
	options 'use' => 'noping-host-https-apma',
		'alias' => 'APMA MGMT',
		'address' => 'admin.japmaonline.org',
		'contact_groups' => 'cs_escalation,apma',
		'notes' => 'APMA Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/APMA/pages/2732523523/Server+Setup+-+American+Podiatric+Medical+Association+APMA'
end
nagios_host 'ams.japmaonline.org' do
	options 'use' => 'noping-host-https-apma',
		'alias' => 'APMA AMS',
		'address' => 'ams.japmaonline.org',
		'contact_groups' => 'cs_escalation,apma',
		'notes' => 'APMA Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/APMA/pages/2732523523/Server+Setup+-+American+Podiatric+Medical+Association+APMA'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live APMA site and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!apma:apma2021!/!"Journal of the American Podiatric Medical Association"!10!20!',
		'contact_groups' => 'cs_escalation,apma',
		'notes' => 'APMA Live Site',
		'notes_url' => 'https://japmaonline.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live apma site on the first web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Homepage: apma-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Homepage: apma-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!apma:apma2021!/!"Journal of the American Podiatric Medical Association"!10!20!apma-web-1-live!apma-web-1.irl.pubfactory.net! --sni',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-web-1',
		'notes_url' => 'https://japmaonline.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live apma site on the sercond web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Homepage: apma-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Homepage: apma-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!apma:apma2021!/!"Journal of the American Podiatric Medical Association"!10!20!apma-web-2-live!apma-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-web-2',
		'notes_url' => 'https://japmaonline.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live APMA site and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!apma:apma2021!/search!Browse!10!20!',
		'contact_groups' => 'cs_escalation,apma',
		'notes' => 'APMA Live Site',
		'notes_url' => 'https://japmaonline.org/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live apma site on the first web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Search: apma-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live search: apma-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!apma:apma2021!/search!Browse!10!20!apma-web-1-live!apma-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-web-1',
		'notes_url' => 'https://japmaonline.org/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live apma site on the second web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Search: apma-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live search: apma-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!apma:apma2021!/search!Browse!10!20!apma-web-2-live!apma-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-web-2',
		'notes_url' => 'https://japmaonline.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live APMA site and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!apma:apma2021!/view/journals/apms/aop/21-194/21-194.xml!suicide!10!20!',
		'contact_groups' => 'cs_escalation,apma',
		'notes' => 'APMA Live Site',
		'notes_url' => 'https://japmaonline.org/view/journals/apms/aop/21-194/21-194.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live apma site on the first web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live content view: apma-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live content view: apma-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!apma:apma2021!/view/journals/apms/aop/21-194/21-194.xml!suicide!10!20!apma-web-1-live!apma-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-web-1',
		'notes_url' => 'https://japmaonline.org/view/journals/apms/aop/21-194/21-194.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live apma site on the sedmond web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live content view: apma-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live content view: apma-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!apma:apma2021!/view/journals/apms/aop/21-194/21-194.xml!suicide!10!20!apma-web-2-live!apma-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-web-2',
		'notes_url' => 'https://japmaonline.org/view/journals/apms/aop/21-194/21-194.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin.japmaonline.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.japmaonline.org!/login!apma:apma2021!"APMA"!20!10',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Loader',
		'notes_url' => 'https://admin.japmaonline.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Journal of the American Podiatric Medical Association' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.japmaonline.org!apma:apma2021!"Journal of the American Podiatric Medical Association"!20!10',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Staging Site',
		'notes_url' => 'staging.japmaonline.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams.japmaonline.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.japmaonline.org!/login!apma:apma2021!AMS!20!10',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA AMX',
		'notes_url' => 'https://ams.japmaonline.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!japmaonline.org!apma:apma2021!"provisional account"',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site Failopen',
		'notes_url' => 'https://japmaonline.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (Node 3)
# Checks the homepage of the live apma.apma site on the bot web node and checks for the string 'APMA'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Homepage: apma-webbot-1 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Homepage: apma-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!apma:2021!/!APMA!10!20!apma-webbot-1-live!apma-webbot-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'apma Site: apma-webbot-1',
		'notes_url' => 'https://www.japmaonline.org/'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 3)
# Checks the search of the live apma.apma site on the first bot web node and checks for the string 'Browse'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live Search: apma-webbot-1 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live Search: apma-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!apma:2021!/search!Browse!10!20!apma-webbot-1-live!apma-webbot-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'apma Site: apma-webbot-1',
		'notes_url' => 'https://www.japmaonline.org/'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 3)
# checks the content view of the live apma site on the first web node and checks for the string 'Journal of the American Podiatric Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'japmaonline.org-Live content view: apma-webbot-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'japmaonline.org',
		'display_name' => 'Live content view: apma-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!apma:apma2021!/view/journals/apms/aop/21-194/21-194.xml!suicide!10!20!apma-webbot-1-live!apma-webbot-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,apma',
		'notes' => 'APMA Live Site: apma-webbot-1',
		'notes_url' => 'https://japmaonline.org/view/journals/apms/aop/21-194/21-194.xml'
end
